@@ -1,11 +1,7 @@
-from typing import TYPE_CHECKING
-
+from poetry.console.application import Application
+from poetry.core.version.pep440.version import PEP440Version
 from poetry.plugins import ApplicationPlugin
 
-if TYPE_CHECKING:
-    from poetry.console.application import Application
-    from poetry.core.version.pep440.version import PEP440Version
-
 
 class Pep440Plugin(ApplicationPlugin):
     def activate(self, application: "Application") -> None:
